@@ -14,9 +14,10 @@ class MainHandler(tornado.web.RequestHandler):
 
     def get(self):
         if 'wsdl' in self.request.arguments:
-            self.set_header( 'Content-Type', 'text/xml' )
             with open('./wsdl.xml') as f:
-                return self.write(f.read())
+                self.write(f.read())
+                self.set_header( 'Content-Type', 'text/xml' )
+                return
         self.write(json.dumps(MainHandler.config, indent=4))
 
     def post(self):
