@@ -29,11 +29,12 @@ def project(wsdl):
     config = service.gen_config()
     with open('./config.json', 'w') as f:
         f.write(json.dumps(config))
-    with open('./wsdl.xml') as f:
+    with open('./wsdl.xml', 'w') as f:
         f.write(wsdl)
     for port in service.ports():
         with open(f'./{port}.xml', 'w') as f:
             f.write(EMPTY_SOAP_RESPONSE)
+    print("Project Generated!")
 
 
 @click.command()
